@@ -861,6 +861,12 @@ Parse STRING and return a boolean value of 1 or 0.  STRING should be formatted a
 
 If STRING is a valid boolean keyword (according to L<validate_boolean_keyword|/validate_boolean_keyword>) or if it looks like a function call (matches /^\w+\(.*\)$/) it is returned unmodified.  Returns undef if STRING could not be parsed as a valid "boolean" value.
 
+=item B<parse_date STRING>
+
+Parse STRING and return a L<DateTime> object.  STRING should be formatted according to the Informix "DATE" data type.
+
+If STRING is a valid date keyword (according to L<validate_date_keyword|/validate_date_keyword>) it is returned unmodified.  Returns undef if STRING could not be parsed as a valid "DATE" value.
+
 =item B<parse_datetime STRING>
 
 Parse STRING and return a L<DateTime> object.  STRING should be formatted according to the Informix "DATETIME YEAR TO SECOND" data type.
